@@ -45,3 +45,13 @@ class SubscriptionRequest(models.Model):
         help = 'How people find us.',
         string = 'Discovery channel'
     )
+    newsletter_approved = fields.Boolean(
+        string='Newsletter approved',
+        required=True,
+        default=False,
+    )
+    sepa_approved = fields.Boolean(
+        string='SEPA approved',
+        required=True,
+        default=False,
+    )
